@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2016 by the fifechan team                               *
+ *   Copyright (c) 2017 by the fifechan team                               *
  *   https://github.com/fifengine/fifechan                                 *
  *   This file is part of fifechan.                                        *
  *                                                                         *
@@ -131,6 +131,7 @@ namespace fcn
         {
             setTop(NULL);
         }
+        Widget::_setVisibilityEventHandler(NULL);
         Widget::_setGuiDeathListener(NULL);
 
         delete mFocusHandler;
@@ -298,6 +299,12 @@ namespace fcn
             case MouseInput::WheelMovedUp:
                handleMouseWheelMovedUp(mouseInput);
                break;
+            case MouseInput::WheelMovedRight:
+               handleMouseWheelMovedRight(mouseInput);
+               break;
+            case MouseInput::WheelMovedLeft:
+               handleMouseWheelMovedLeft(mouseInput);
+               break;
             default:
                throw FCN_EXCEPTION("Unknown mouse input type.");
                break;
@@ -562,6 +569,40 @@ namespace fcn
                              mouseInput.getY());
     }
 
+    void Gui::handleMouseWheelMovedRight(const MouseInput& mouseInput)
+    {
+        Widget* sourceWidget = getMouseEventSource(mouseInput.getX(), mouseInput.getY());
+
+        if (mFocusHandler->getDraggedWidget() != NULL)
+            sourceWidget = mFocusHandler->getDraggedWidget();
+
+        int sourceWidgetX, sourceWidgetY;
+        sourceWidget->getAbsolutePosition(sourceWidgetX, sourceWidgetY);
+
+        distributeMouseEvent(sourceWidget,
+                             MouseEvent::WheelMovedRight,
+                             mouseInput.getButton(),
+                             mouseInput.getX(),
+                             mouseInput.getY());
+    }
+
+    void Gui::handleMouseWheelMovedLeft(const MouseInput& mouseInput)
+    {
+        Widget* sourceWidget = getMouseEventSource(mouseInput.getX(), mouseInput.getY());
+
+        if (mFocusHandler->getDraggedWidget() != NULL)
+            sourceWidget = mFocusHandler->getDraggedWidget();
+
+        int sourceWidgetX, sourceWidgetY;
+        sourceWidget->getAbsolutePosition(sourceWidgetX, sourceWidgetY);
+
+        distributeMouseEvent(sourceWidget,
+                             MouseEvent::WheelMovedLeft,
+                             mouseInput.getButton(),
+                             mouseInput.getX(),
+                             mouseInput.getY());
+    }
+
     void Gui::handleMouseReleased(const MouseInput& mouseInput)
     {
         Widget* sourceWidget = getMouseEventSource(mouseInput.getX(), mouseInput.getY());
@@ -743,6 +784,12 @@ namespace fcn
                       case MouseEvent::WheelMovedDown:
                           (*it)->mouseWheelMovedDown(mouseEvent);
                           break;
+                      case MouseEvent::WheelMovedRight:
+                          (*it)->mouseWheelMovedRight(mouseEvent);
+                          break;
+                      case MouseEvent::WheelMovedLeft:
+                          (*it)->mouseWheelMovedLeft(mouseEvent);
+                          break;
                       case MouseEvent::Dragged:
                           (*it)->mouseDragged(mouseEvent);
                           break;
