@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2016 by the fifechan team                               *
+ *   Copyright (c) 2017 by the fifechan team                               *
  *   https://github.com/fifengine/fifechan                                 *
  *   This file is part of fifechan.                                        *
  *                                                                         *
@@ -80,7 +80,6 @@
 #include "fifechan/keylistener.hpp"
 #include "fifechan/mouseinput.hpp"
 #include "fifechan/mouselistener.hpp"
-#include "fifechan/sizeconstraint.hpp"
 #include "fifechan/visibilityeventhandler.hpp"
 #include "fifechan/widgetlistener.hpp"
 
@@ -103,7 +102,6 @@ namespace fcn
               mInternalFocusHandler(NULL),
               mParent(NULL),
               mFrameSize(0),
-              mSizeConstraint(NULL),
               mFocusable(false),
               mVisible(true),
               mTabIn(true),
@@ -118,8 +116,6 @@ namespace fcn
 
     Widget::~Widget()
     {
-        delete mSizeConstraint;
-        
         if (mParent != NULL)
             mParent->remove(this);
 
@@ -247,11 +243,6 @@ namespace fcn
         if (mDimension.width != oldDimension.width
             || mDimension.height != oldDimension.height)
         {
-            if(hasSizeConstraint())
-            {
-                enforceSizeConstraint();   
-            }
-            
             distributeResizedEvent();
         }
 
@@ -348,8 +339,6 @@ namespace fcn
         if (!visible && isFocused())
             mFocusHandler->focusNone();
         
-        mVisible = visible;
-        
         if (visible)
         {
             visibilityEventHandler->widgetShown(Event(this));
@@ -376,6 +365,8 @@ namespace fcn
                 (*currChild)->distributeAncestorHiddenEvent(this);
             }
         }
+
+        mVisible = visible;
     }
 
     bool Widget::isVisible() const
@@ -462,22 +453,6 @@ namespace fcn
         return mFocusHandler;
     }
     
-    void Widget::_setWidthWithoutNotifying(int width)
-    {
-        mDimension.width = width;
-    }
-    
-    void Widget::_setHeightWithoutNotifying(int height)
-    {
-        mDimension.height = height;
-    }
-    
-    void Widget::_setSizeWithoutNotifying(int width, int height)
-    {
-        mDimension.width = width;
-        mDimension.height = height;
-    }
-    
     void Widget::_setVisibilityEventHandler(VisibilityEventHandler* visibilityEventHandler)
     { 
         mVisibilityEventHandler = visibilityEventHandler;    
@@ -931,23 +906,6 @@ namespace fcn
         if (mParent != NULL)
             mParent->showWidgetPart(this, rectangle);               
     }
-    
-    void Widget::setSizeConstraint(SizeConstraint* sizeConstraint)
-    {
-        delete mSizeConstraint;
-        mSizeConstraint = sizeConstraint;
-        enforceSizeConstraint();
-    }
-    
-    SizeConstraint* Widget::getSizeConstraint() const
-    {
-        return mSizeConstraint;
-    }
-    
-    bool Widget::hasSizeConstraint() const
-    {
-        return mSizeConstraint != NULL;
-    }
 
     Widget* Widget::getTop() const
     {
@@ -989,34 +947,15 @@ namespace fcn
         for (iter = mChildren.begin(); iter != mChildren.end(); iter++)
         {
             Widget* widget = (*iter);
-            if(widget->isVisible())
-            {
-                if (widget->getX() + widget->getWidth() > w)
-                    w = widget->getX() + widget->getWidth();
+            if (widget->getX() + widget->getWidth() > w)
+                w = widget->getX() + widget->getWidth();
 
-                if (widget->getY() + widget->getHeight() > h)
-                    h = widget->getY() + widget->getHeight();
-            }
+            if (widget->getY() + widget->getHeight() > h)
+                h = widget->getY() + widget->getHeight();
         }
         
         setSize(w, h);
     }
-    
-    void Widget::enforceSizeConstraint()
-    {
-        if(mSizeConstraint == NULL)
-            throw FCN_EXCEPTION("Enforcing a non-existent size constraint");
-        
-        int minWidth = mSizeConstraint->getMinWidth();
-        int minHeight = mSizeConstraint->getMinHeight();
-        int maxWidth = mSizeConstraint->getMaxWidth();
-        int maxHeight = mSizeConstraint->getMaxHeight();
-        int currWidth = mDimension.width;
-        int currHeight = mDimension.height;
-        
-        mDimension.width = std::max(std::min(currWidth, maxWidth), minWidth);
-        mDimension.height = std::max(std::min(currHeight, maxHeight), minHeight);
-    }
 
     Widget* Widget::findWidgetById(const std::string& id)
     {
