@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2016 by the fifechan team                               *
+ *   Copyright (c) 2017 by the fifechan team                               *
  *   https://github.com/fifengine/fifechan                                 *
  *   This file is part of fifechan.                                        *
  *                                                                         *
@@ -1116,19 +1116,12 @@ namespace fcn
         if (mouseEvent.isConsumed())
             return;
 
-        if (!mVBarVisible && !mHBarVisible) {
+        if (!mVBarVisible) {
             mouseEvent.consume();
             return;
         }
-        bool scrollV = mVBarVisible;
-        if (mVBarVisible && mHBarVisible) {
-            scrollV = getVerticalMaxScroll() > getHorizontalMaxScroll();
-        }
-        if (scrollV) {
-            setVerticalScrollAmount(getVerticalScrollAmount() - getChildrenArea().height / 8);
-        } else {
-            setHorizontalScrollAmount(getHorizontalScrollAmount() - getChildrenArea().width / 8);
-        }
+
+        setVerticalScrollAmount(getVerticalScrollAmount() - getChildrenArea().height / 8);
 
         mouseEvent.consume();
     }
@@ -1138,20 +1131,43 @@ namespace fcn
         if (mouseEvent.isConsumed())
             return;
 
-        if (!mVBarVisible && !mHBarVisible) {
+        if (!mVBarVisible) {
             mouseEvent.consume();
             return;
         }
-        bool scrollV = mVBarVisible;
-        if (mVBarVisible && mHBarVisible) {
-            scrollV = getVerticalMaxScroll() > getHorizontalMaxScroll();
+
+        setVerticalScrollAmount(getVerticalScrollAmount() + getChildrenArea().height / 8);
+
+        mouseEvent.consume();
+    }
+
+    void ScrollArea::mouseWheelMovedRight(MouseEvent& mouseEvent)
+    {
+        if (mouseEvent.isConsumed())
+            return;
+
+        if (!mHBarVisible) {
+            mouseEvent.consume();
+            return;
         }
-        if (scrollV) {
-            setVerticalScrollAmount(getVerticalScrollAmount() + getChildrenArea().height / 8);
-        } else {
-            setHorizontalScrollAmount(getHorizontalScrollAmount() + getChildrenArea().width / 8);
+
+        setHorizontalScrollAmount(getHorizontalScrollAmount() + getChildrenArea().width / 8);
+
+        mouseEvent.consume();
+    }
+
+    void ScrollArea::mouseWheelMovedLeft(MouseEvent& mouseEvent)
+    {
+        if (mouseEvent.isConsumed())
+            return;
+
+        if (!mHBarVisible) {
+            mouseEvent.consume();
+            return;
         }
 
+        setHorizontalScrollAmount(getHorizontalScrollAmount() - getChildrenArea().width / 8);
+
         mouseEvent.consume();
     }
 
